#!/bin/bash

tag=$(rpmspec -q --qf="%{version}\n" --srpm ./*.spec)
url=$(rpmspec -q --qf="%{url}\n" --srpm ./*.spec)
pkgdir=$(rpmspec -q --qf="%{name}" --srpm ./*.spec | sed -e 's/^nodejs-//')

echo "tag: $tag"
echo "URL: $url"
echo "pkgdir: $pkgdir"

set -e

tmp=$(mktemp -d)

trap cleanup EXIT
cleanup() {
    echo Cleaning up...
    set +e
    [ -z "$tmp" -o ! -d "$tmp" ] || rm -rf "$tmp"
}

unset CDPATH
pwd=$(pwd)

pushd "$tmp"
git clone https://github.com/babel/babel
newdir=packages/$pkgdir
cd babel
echo Finding git tag
gittag=$(git show-ref --tags | cut -d' ' -f2 | grep "tags/v${tag}$" | head -n1 || git show-ref --tags | cut -d' ' -f2 | sort -Vr | head -n1)
if [ -z $gittag ]; then
	gittag=tags/$tag
	echo "Could not find tag $tag, using $gittag instead"
fi
echo "Git Tag: $gittag"
if [ -d "$newdir/test" ]; then
  git archive --prefix='test/' --format=tar ${gittag}:$newdir/test/ \
      | bzip2 > "$pwd"/$pkgdir-tests-${tag}.tar.bz2
elif [ -d "$newdir/tests" ]; then
  git archive --prefix='tests/' --format=tar ${gittag}:$newdir/tests/ \
      | bzip2 > "$pwd"/$pkgdir-tests-${tag}.tar.bz2
elif [ -d "$newdir/spec" ]; then
  git archive --prefix='spec/' --format=tar ${gittag}:$newdir/spec/ \
      | bzip2 > "$pwd"/$pkgdir-tests-${tag}.tar.bz2
else
  echo "No test directory found for tag ${gittag}"
fi
if [ -d "$newdir/support" ]; then
  git archive --prefix='support/' --format=tar ${gittag}:$newdir/support/ \
      | bzip2 > "$pwd"/$pkgdir-support-${tag}.tar.bz2
fi
if [ -d "$newdir/fixture" ]; then
  git archive --prefix='fixture/' --format=tar ${gittag}:$newdir/fixture/ \
      | bzip2 > "$pwd"/$pkgdir-fixture-${tag}.tar.bz2
fi
if [ -d "$newdir/examples" ]; then
  git archive --prefix='examples/' --format=tar ${gittag}:$newdir/examples/ \
      | bzip2 > "$pwd"/$pkgdir-examples-${tag}.tar.bz2
elif [ -d "$newdir/example" ]; then
  git archive --prefix='example/' --format=tar ${gittag}:$newdir/example/ \
      | bzip2 > "$pwd"/$pkgdir-examples-${tag}.tar.bz2
fi
if [ -d "$newdir/tasks" ]; then
  git archive --prefix='tasks/' --format=tar ${gittag}:$newdir/tasks/ \
      | bzip2 > "$pwd"/$pkgdir-tasks-${tag}.tar.bz2
fi
if [ -d "$newdir/docs" ]; then
  git archive --prefix='docs/' --format=tar ${gittag}:$newdir/docs/ \
      | bzip2 > "$pwd"/$pkgdir-docs-${tag}.tar.bz2
elif [ -d "$newdir/doc" ]; then
  git archive --prefix='doc/' --format=tar ${gittag}:$newdir/doc/ \
      | bzip2 > "$pwd"/$pkgdir-docs-${tag}.tar.bz2
fi
if [ -d "$newdir/src" ]; then
  git archive --prefix='src/' --format=tar ${gittag}:$newdir/src/ \
      | bzip2 > "$pwd"/$pkgdir-src-${tag}.tar.bz2
elif [ -d "$newdir/source" ]; then
  git archive --prefix='source/' --format=tar ${gittag}:$newdir/source/ \
      | bzip2 > "$pwd"/$pkgdir-source-${tag}.tar.bz2
fi
if [ -d "$newdir/tools" ]; then
  git archive --prefix='tools/' --format=tar ${gittag}:$newdir/tools/ \
      | bzip2 > "$pwd"/$pkgdir-tools-${tag}.tar.bz2
fi
if [ -d "$newdir/scripts" ]; then
  git archive --prefix='scripts/' --format=tar ${gittag}:$newdir/scripts/ \
      | bzip2 > "$pwd"/$pkgdir-scripts-${tag}.tar.bz2
fi
if [ -d "$newdir/modules" ]; then
  git archive --prefix='modules/' --format=tar ${gittag}:$newdir/modules/ \
      | bzip2 > "$pwd"/$pkgdir-modules-${tag}.tar.bz2
fi
if [ -d "$newdir/ts" ]; then
  git archive --prefix='ts/' --format=tar ${gittag}:$newdir/ts/ \
      | bzip2 > "$pwd"/$pkgdir-ts-${tag}.tar.bz2
fi
if [ -d "$newdir/build" ]; then
  git archive --prefix='build/' --format=tar ${gittag}:$newdir/build/ \
      | bzip2 > "$pwd"/$pkgdir-build-${tag}.tar.bz2
fi
if [ -d "$newdir/fixtures" ]; then
  git archive --prefix='fixtures/' --format=tar ${gittag}:$newdir/fixtures/ \
      | bzip2 > "$pwd"/$pkgdir-fixtures-${tag}.tar.bz2
fi
if [ -d "$newdir/mocks" ]; then
  git archive --prefix='mocks/' --format=tar ${gittag}:$newdir/mocks/ \
      | bzip2 > "$pwd"/$pkgdir-mocks-${tag}.tar.bz2
fi
if [ -d "$newdir/typings" ]; then
  git archive --prefix='typings/' --format=tar ${gittag}:$newdir/typings/ \
      | bzip2 > "$pwd"/$pkgdir-typings-${tag}.tar.bz2
fi
if [ -d "$newdir/templates" ]; then
  git archive --prefix='templates/' --format=tar ${gittag}:$newdir/templates/ \
      | bzip2 > "$pwd"/$pkgdir-templates-${tag}.tar.bz2
fi
if [ -d "$newdir/benchmark" ]; then
  git archive --prefix='benchmark/' --format=tar ${gittag}:$newdir/benchmark/ \
      | bzip2 > "$pwd"/$pkgdir-benchmark-${tag}.tar.bz2
fi
if [ -d "$newdir/vendor" ]; then
  git archive --prefix='vendor/' --format=tar ${gittag}:$newdir/vendor/ \
      | bzip2 > "$pwd"/$pkgdir-vendor-${tag}.tar.bz2
fi
if [ -d "$newdir/packages" ]; then
  git archive --prefix='packages/' --format=tar ${gittag}:$newdir/packages/ \
      | bzip2 > "$pwd"/$pkgdir-packages-${tag}.tar.bz2
fi
if [ -d "$newdir/rollup" ]; then
  git archive --prefix='rollup/' --format=tar ${gittag}:$newdir/rollup/ \
      | bzip2 > "$pwd"/$pkgdir-rollup-${tag}.tar.bz2
fi
popd
